==> openwhisk-runtime-swift-1.15.0-sources.tar.gz: openwhisk-runtime-swift-1.15.0/tests/dat/actions/SwiftyRequestCodable5/Sources/main.swift <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import SwiftyRequest
import Dispatch
import Foundation

enum RequestError: Error {
    case requetError
}
struct AnInput: Codable {
    let url: String?
}
struct AnOutput: Codable {
    let greeting: String?
}
func main(param: AnInput, completion: @escaping (AnOutput?, Error?) -> Void) -> Void {
    let echoURL = param.url ?? "https://httpbin.org/get"
    let request = RestRequest(method: .get, url: echoURL)
    request.responseString { result in
        switch result {
        case .success(let response):
            print(response)
            completion(AnOutput(greeting:"success"),nil)
        case .failure(let error):
            print(error)
            completion(nil,RequestError.requetError)
        }
    }
}

==> openwhisk-runtime-swift-1.19.0-sources.tar.gz: openwhisk-runtime-swift-1.19.0/tests/dat/actions/SwiftyRequestCodable5/Sources/main.swift <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import SwiftyRequest
import Dispatch
import Foundation

enum RequestError: Error {
    case requestError
}
struct AnInput: Codable {
    let url: String?
}
struct AnOutput: Codable {
    let greeting: String?
}
func main(param: AnInput, completion: @escaping (AnOutput?, Error?) -> Void) -> Void {
    let echoURL = param.url ?? "https://httpbin.org/get"
    let request = RestRequest(method: .get, url: echoURL)
    request.responseString { result in
        switch result {
        case .success(let response):
            print(response)
            completion(AnOutput(greeting:"success"),nil)
        case .failure(let error):
            print(error)
            completion(nil,RequestError.requestError)
        }
    }
}
